==> facebook-nodejs-business-sdk-4.0.8.tgz: package/docs/IG_ACCOUNT_GET.js <==
/**
 * Copyright (c) 2017-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE file in the root directory of this source tree.
 * @flow
 */

const bizSdk = require('facebook-nodejs-business-sdk');
const process = require('process');
const Page = bizSdk.Page;

let app_id = '1224202007596125';
let access_token = 'EAARZAZA73LzF0BACZADSZCYwMsLHUTwAAYKm5Tciz5GZCGM8ZAtqoM12q8ybFt6dpElSqbUuXm77dGmZAeK6r1wygAQZCslDqpsVQY6RQA3WhLirP8BcgoKoCTvlyKzkx6xGPZCcRiDXUleDqSbnAQBd5k0ZBhuLf1AB2VsIS5OlYDoTQlOoRuVpmZAiJY9O6d688sZD';
let app_secret = '709348c9665c33a4f988ff3950098131';
let page_access_token_for_ig = 'EAAXpG75bQZBIBACZAtJMLZAp7Ib2ZAOWyocd6MmcZAAkJTOoWRkmWe4dGnbZBXzYchdHFNMln9hMrS2Qp9p4huLYZCSZAT28qKx42CeoErBd8ZCFObHNmLBMvVBGuLNJNMXwIOyPlizurYd1pm1CBnqh4zww2Inf5jMnCpTpfm8ZAPxE0XA78panZBJ';
let page_id_for_ig = '1322842141107011';
const api = bizSdk.FacebookAdsApi.init(
  access_token
);
const showDebugingInfo = true; // Setting this to true shows more debugging info.
if (showDebugingInfo) {
  api.setDebug(true);
}

const logApiCallResult = (apiCallName, data) => {
  console.log(apiCallName);
  if (showDebugingInfo) {
    console.log('Data:' + JSON.stringify(data));
  }
};
let fields, params;
void async function() {
try {
//  _DOC oncall [ellentao]
//  _DOC open [IG_ACCOUNT_GET]
//  _DOC vars [page_id_for_ig]
bizSdk.FacebookAdsApi.init(page_access_token_for_ig);
fields = [
  'instagram_business_account',
];
params = {
};
let page = await (new Page(page_id_for_ig)).get(
  fields,
  params
);

//  _DOC close [IG_ACCOUNT_GET]
}
catch(error) {
  console.log(error);
  process.exit(1);
}
}();

==> facebook-nodejs-business-sdk-6.0.0.tgz: package/docs/IG_ACCOUNT_GET.js <==
/**
 * Copyright (c) 2017-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE file in the root directory of this source tree.
 * @flow
 */

const bizSdk = require('facebook-nodejs-business-sdk');
const process = require('process');
const Page = bizSdk.Page;

let app_id = '1224202007596125';
let access_token = 'EAARZAZA73LzF0BACZADSZCYwMsLHUTwAAYKm5Tciz5GZCGM8ZAtqoM12q8ybFt6dpElSqbUuXm77dGmZAeK6r1wygAQZCslDqpsVQY6RQA3WhLirP8BcgoKoCTvlyKzkx6xGPZCcRiDXUleDqSbnAQBd5k0ZBhuLf1AB2VsIS5OlYDoTQlOoRuVpmZAiJY9O6d688sZD';
let app_secret = '709348c9665c33a4f988ff3950098131';
let page_access_token_for_ig = 'EAAXpG75bQZBIBACZAtJMLZAp7Ib2ZAOWyocd6MmcZAAkJTOoWRkmWe4dGnbZBXzYchdHFNMln9hMrS2Qp9p4huLYZCSZAT28qKx42CeoErBd8ZCFObHNmLBMvVBGuLNJNMXwIOyPlizurYd1pm1CBnqh4zww2Inf5jMnCpTpfm8ZAPxE0XA78panZBJ';
let page_id_for_ig = '1322842141107011';
const api = bizSdk.FacebookAdsApi.init(
  access_token,
  crash_log=false
);
const showDebugingInfo = true; // Setting this to true shows more debugging info.
if (showDebugingInfo) {
  api.setDebug(true);
}

const logApiCallResult = (apiCallName, data) => {
  console.log(apiCallName);
  if (showDebugingInfo) {
    console.log('Data:' + JSON.stringify(data));
  }
};
let fields, params;
void async function() {
try {
//  _DOC oncall [ellentao]
//  _DOC open [IG_ACCOUNT_GET]
//  _DOC vars [page_id_for_ig]
bizSdk.FacebookAdsApi.init(page_access_token_for_ig, crash_log=false);
fields = [
  'instagram_business_account',
];
params = {
};
let page = await (new Page(page_id_for_ig)).get(
  fields,
  params
);

//  _DOC close [IG_ACCOUNT_GET]
}
catch(error) {
  console.log(error);
  process.exit(1);
}
}();
